@@ -67,7 +67,7 @@ class RecurrenceField(forms.CharField):
     """
     widget = RecurrenceWidget
     default_error_messages = {
-        'invalid_freqency': _(
+        'invalid_frequency': _(
             u'Invalid frequency.'),
         'max_rrules_exceeded': _(
             u'Max rules exceeded. The limit is %(limit)s'),
@@ -83,7 +83,8 @@ class RecurrenceField(forms.CharField):
         self,
         frequencies=None, accept_dtstart=True, accept_dtend=True,
         max_rrules=None, max_exrules=None, max_rdates=None, max_exdates=None,
-        *args, **kwargs):
+        *args, **kwargs
+    ):
         """
         Create a recurrence field.
 
@@ -145,8 +146,6 @@ class RecurrenceField(forms.CharField):
             recurrence_obj = recurrence.deserialize(value)
         except exceptions.DeserializationError as error:
             raise forms.ValidationError(error.args[0])
-        except exceptions.ValidationError as error:
-            raise forms.ValidationError(error.args[0])
 
         if not self.accept_dtstart:
             recurrence_obj.dtstart = None
@@ -157,22 +156,30 @@ class RecurrenceField(forms.CharField):
             if len(recurrence_obj.rrules) > self.max_rrules:
                 raise forms.ValidationError(
                     self.error_messages['max_rrules_exceeded'] % {
-                    'limit': self.max_rrules})
+                        'limit': self.max_rrules
+                    }
+                )
         if self.max_exrules is not None:
             if len(recurrence_obj.exrules) > self.max_exrules:
                 raise forms.ValidationError(
                     self.error_messages['max_exrules_exceeded'] % {
-                    'limit': self.max_exrules})
+                        'limit': self.max_exrules
+                    }
+                )
         if self.max_rdates is not None:
             if len(recurrence_obj.rdates) > self.max_rdates:
                 raise forms.ValidationError(
                     self.error_messages['max_rdates_exceeded'] % {
-                    'limit': self.max_rdates})
+                        'limit': self.max_rdates
+                    }
+                )
         if self.max_exdates is not None:
             if len(recurrence_obj.exdates) > self.max_exdates:
                 raise forms.ValidationError(
                     self.error_messages['max_exdates_exceeded'] % {
-                    'limit': self.max_exdates})
+                        'limit': self.max_exdates
+                    }
+                )
 
         for rrule in recurrence_obj.rrules:
             if rrule.freq not in self.frequencies:
